Stan Math Library: stan::is_constant_struct< std::vector< T > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::is_constant_struct< std::vector< T > > Struct Template Reference

`#include <is_constant_struct.hpp>`

## Public Types
enum | { value = is_constant_struct<T>::value }

## Detailed Description

### template<typename T>
struct stan::is_constant_struct< std::vector< T > >

Definition at line 11 of file is_constant_struct.hpp.

## Member Enumeration Documentation

template<typename T >

anonymous enum

Enumerator
value |

Definition at line 12 of file is_constant_struct.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/arr/meta/is_constant_struct.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.